# coding: utf-8

from __future__ import unicode_literals

import logging
import os

from tionix_autosetup.executors.base import MODULES_CONF_DIR, Dirs
from tionix_autosetup.executors.config import (
    Config, DropConfig, RenameConfig, UpdateYamlConfig,
    ActualizeConfig, DropPath)
from tionix_autosetup.executors.keystone import KeystoneConnectionCheck
from tionix_autosetup.executors.mysql import (
    DbConnectionCheck, MysqlDropCommands, MysqlCommands)
from tionix_autosetup.executors.rabbit import (
    RabbitMQConnectionCheck, DropRabbitVhost, RabbitCommands)
from tionix_autosetup.executors.package import (
    Install, Update, Uninstall)
from tionix_autosetup.executors.service import (
    Migration, SystemServicesRestart, RunConfiguration)
from tionix_autosetup.helpers import PackageTypesEnum

logger = logging.getLogger(__name__)

config_name = 'monitor.yaml'

dirs = ['/var/log/tionix/monitor']
package_names = {
    PackageTypesEnum.PIP: 'tionix-monitor',
    PackageTypesEnum.RPM: 'python-module-tionix_monitor',
}


class MonitorMakeDirs(Dirs):
    dirs = dirs


class MonitorDropPath(DropPath):
    paths = dirs


class MonitorConfig(Config):
    config_path = os.path.join(MODULES_CONF_DIR, config_name)
    template_name = 'monitor_config.template'


class MonitorMigration(Migration):
    module_name = 'tnx_monitor'


class UpdateMonitorYamlConfig(UpdateYamlConfig, MonitorConfig):
    pass


class MonitorDropConfig(DropConfig):
    config_name = config_name


class MonitorRenameConfig(RenameConfig):
    config_name = config_name


class MonitorActualizeConfig(ActualizeConfig):
    config_name = config_name


class InstallMonitor(Install):
    package_names = package_names


class UpdateMonitor(Update):
    package_names = package_names


class UninstallMonitor(Uninstall):
    package_names = package_names


class MonitorConfiguration(RunConfiguration):
    module_names = 'tnx_monitor'


pipeline = [
    InstallMonitor,
    MonitorConfiguration,
    MonitorMakeDirs,
    MonitorConfig,
    UpdateMonitorYamlConfig,
    MonitorActualizeConfig,
    MysqlCommands,
    MonitorMigration,
    RabbitCommands,
    SystemServicesRestart,
]

update_pipeline = [
    UpdateMonitor,
    MonitorConfiguration,
    UpdateMonitorYamlConfig,
    MonitorActualizeConfig,
    MonitorMigration,
    SystemServicesRestart,
]

uninstall_pipeline = [
    UninstallMonitor,
    MonitorRenameConfig,
    MysqlDropCommands,
    DropRabbitVhost,
    MonitorDropConfig,
    MonitorDropPath,
    SystemServicesRestart,
]

connections_check_pipeline = [
    DbConnectionCheck,
    KeystoneConnectionCheck,
    RabbitMQConnectionCheck,
]

post_check_pipeline = []
