# coding: utf-8

from __future__ import unicode_literals

import logging
import os

from tionix_autosetup.executors.base import MODULES_CONF_DIR, Dirs
from tionix_autosetup.executors.config import (
    DropPath, DropConfig, RenameConfig, DropSupervisorConfig, Config,
    ConfigWithSectionsParser, UpdateYamlConfig, ActualizeConfig)
from tionix_autosetup.executors.mysql import (
    DbConnectionCheck, MysqlDropCommands, MysqlCommands)
from tionix_autosetup.executors.rabbit import (
    RabbitMQConnectionCheck, DropRabbitVhost, RabbitCommands)
from tionix_autosetup.executors.keystone import KeystoneConnectionCheck
from tionix_autosetup.executors.package import (
    Install, Update, Uninstall)
from tionix_autosetup.executors.service import (
    SystemServicesRestart, Migration, RunConfiguration)
from tionix_autosetup.executors.apache import (
    ApacheRestart, DropApacheConfig, UpdateApacheConfig, ApacheConfigPathMixin,
    CopyApacheConfig)
from tionix_autosetup.helpers import PackageTypesEnum


logger = logging.getLogger(__name__)
dirs = ['/var/log/tionix/vdi-server']
config_name = 'vdi_server.yaml'
module_config_prefix = 'tnx_vdi'
apache_config_name = 'tionix-vdi-server.conf'


package_names = {
    PackageTypesEnum.PIP: 'tionix-vdi-server',
    PackageTypesEnum.RPM: 'python-module-tionix_vdi_server',
}


horizon_apache_configs = (
    '/etc/apache2/conf-available/openstack-dashboard.conf',
    '/etc/httpd2/conf/sites-available/openstack-dashboard.conf',
    '/etc/httpd/conf/sites-available/openstack-dashboard.conf',
    '/etc/httpd/conf.d/openstack-dashboard.conf',
)
tionix_vdi_worker = 'tionix-vdi-worker'
tionix_vdi_keystone_monitor = 'tionix-vdi-keystone-monitor'


class VDIServerMigration(Migration):
    module_name = 'tnx_vdi_server'


class VDIServerConfiguration(RunConfiguration):
    module_names = 'tnx_vdi_server'


class VDIServerCopyApacheConfig(CopyApacheConfig):
    cfg_name = apache_config_name


class ConfigWithSectionsParserVDIWorker(ConfigWithSectionsParser):
    config_path = '/etc/supervisor/conf.d/tnx_vdi_worker.conf'
    config_section = 'program:{0}'.format(tionix_vdi_worker)
    config_keys = {
        'user': '{TNX_USERNAME}',
        'group': '{TNX_USERNAME}',
    }


class ConfigKeystoneMonitorWorker(ConfigWithSectionsParser):
    config_path = '/etc/supervisor/conf.d/tnx_vdi_keystone_monitor.conf'
    config_section = 'program:' + tionix_vdi_keystone_monitor
    config_keys = {
        'user': '{TNX_USERNAME}',
        'group': '{TNX_USERNAME}',
    }


class VDIServerUpdateApacheConfig(ApacheConfigPathMixin, UpdateApacheConfig):
    config_name = apache_config_name


class VDIServerConfig(Config):
    config_path = os.path.join(MODULES_CONF_DIR, config_name)
    template_name = 'vdi_server_config.template'


class UpdateVDIServerYamlConfig(UpdateYamlConfig, VDIServerConfig):
    pass


class VDIServerDirs(Dirs):
    dirs = dirs


class VDIServerDropConfig(DropConfig):
    config_name = config_name


class VDIServerActualizeConfig(ActualizeConfig):
    config_name = config_name


class VDIServerDropSupervisorConfig(DropSupervisorConfig):
    module_config_prefix = module_config_prefix


class VDIServerDropApacheConfig(DropApacheConfig):
    config_name = 'tionix-vdi-server.conf'


class VDIServerRenameConfig(RenameConfig):
    config_name = config_name


class VDIServerDropLogFiles(DropPath):
    paths = dirs


class InstallVDIServer(Install):
    package_names = package_names


class UpdateVDIServer(Update):
    package_names = package_names


class UninstallVDIServer(Uninstall):
    package_names = package_names


pipeline = [
    InstallVDIServer,
    VDIServerConfiguration,
    VDIServerDirs,
    VDIServerConfig,
    UpdateVDIServerYamlConfig,
    VDIServerActualizeConfig,
    MysqlCommands,
    RabbitCommands,
    VDIServerCopyApacheConfig,
    ConfigWithSectionsParserVDIWorker,
    ConfigKeystoneMonitorWorker,
    VDIServerUpdateApacheConfig,
    VDIServerMigration,
    ApacheRestart,
    SystemServicesRestart,
]

update_pipeline = [
    UpdateVDIServer,
    VDIServerConfiguration,
    UpdateVDIServerYamlConfig,
    VDIServerActualizeConfig,
    VDIServerMigration,
    ApacheRestart,
    SystemServicesRestart,
]

uninstall_pipeline = [
    UninstallVDIServer,
    VDIServerRenameConfig,
    MysqlDropCommands,
    DropRabbitVhost,
    VDIServerDropConfig,
    VDIServerDropSupervisorConfig,
    VDIServerDropApacheConfig,
    VDIServerDropLogFiles,
    ApacheRestart,
    SystemServicesRestart,
]

connections_check_pipeline = [
    DbConnectionCheck,
    KeystoneConnectionCheck,
    RabbitMQConnectionCheck,
]

post_check_pipeline = []
